####################################
Velleman K8090 8-channel relay board
####################################

.. autoclass:: pymeasure.instruments.velleman.VellemanK8090
    :members:
    :show-inheritance:

.. autoclass:: pymeasure.instruments.velleman.VellemanK8090Switches
    :show-inheritance:
